@@ -6,11 +6,8 @@ class HistoryOfPresentIllnessCommand(_BaseCommand):
 
     class Meta:
         key = "hpi"
-        commit_required_fields = ("narrative",)
 
     narrative: str | None = None
 
-    @property
-    def values(self) -> dict:
-        """The HPI command's field values."""
-        return {"narrative": self.narrative}
+
+__exports__ = ("HistoryOfPresentIllnessCommand",)
