@@ -8,7 +8,6 @@ class StopMedicationCommand(_BaseCommand):
 
     class Meta:
         key = "stopMedication"
-        commit_required_fields = ("medication_id",)
 
     # how do we make sure this is a valid medication_id for the patient?
     medication_id: str | None = Field(
@@ -16,7 +15,5 @@ class StopMedicationCommand(_BaseCommand):
     )
     rationale: str | None = None
 
-    @property
-    def values(self) -> dict:
-        """The StopMedication command's field values."""
-        return {"medication_id": self.medication_id, "rationale": self.rationale}
+
+__exports__ = ("StopMedicationCommand",)
