@@ -10,7 +10,7 @@ class RemoveBannerAlert(_BaseEffect):
 
     class Meta:
         effect_type = EffectType.REMOVE_BANNER_ALERT
-        apply_required_fields = ("patient_id", "key")
+        apply_required_fields = ("patient_id|patient_filter", "key")
 
     patient_id: str | None = None
     key: str | None = None
@@ -18,4 +18,7 @@ class RemoveBannerAlert(_BaseEffect):
     @property
     def effect_payload(self) -> dict[str, Any]:
         """The payload of the effect."""
-        return {"patient": self.patient_id, "key": self.key}
+        return {"patient": self.patient_id, "patient_filter": self.patient_filter, "key": self.key}
+
+
+__exports__ = ("RemoveBannerAlert",)
